using Pkg
Pkg.activate(".")
Pkg.instantiate()
using GLPK
using HydroPowerModels

#' ## Initialization
using Random
seed = 1221

#' ## Load Case Specifications
#' Data
alldata = HydroPowerModels.parse_folder(".//case3");

#' Plot power grid graph
Random.seed!(seed)
HydroPowerModels.plot_grid(alldata[1],node_label=false)


#' Parameters
params = create_param(  stages = 12, 
                        model_constructor_grid  = DCPPowerModel,
                        post_method             = PowerModels.post_opf,
                        optimizer               = with_optimizer(GLPK.Optimizer));

#' ## Build Model
m = hydrothermaloperation(alldata, params);

#' ## Train
start_time = time()
HydroPowerModels.train(m,iteration_limit = 100,stopping_rules= [SDDP.Statistical(num_replications = 50,iteration_period=50)]);
end_time = time() - start_time

#' Termination Status and solve time (s)
(SDDP.termination_status(m.policygraph), end_time)

#' Bounds
HydroPowerModels.plot_bound(m)

#' ## Simulation
import Random
Random.seed!(seed)
results = HydroPowerModels.simulate(m, 100)

#' ## Plot Aggregated Results
HydroPowerModels.plot_aggregated_results(results)
